/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tmc;

import de.bsvrz.kex.lmstic3.vew.daten.tmc.TMCRichtung.TMCRichtungEnum;

/**
 * TMC-Lokationsinformationen.
 * 
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: TMCLocation.java 63650 2016-09-22 17:11:32Z gieseler $
 */
public class TMCLocation {

	private Integer primaerLokation;
	private Integer sekundaerLokation;

	private Double primaerEntfernung;
	private Double sekundaerEntfernung;
	private TMCRichtungEnum tmcRichtung;

	/**
	 * Konstruktor.
	 * 
	 * @param primaerLokation
	 *            Primaerlokation
	 * @param sekundaerLokation
	 *            Sekundaerlokation
	 * @param primaerEntfernung
	 *            Primaerentfernung
	 * @param sekundaerEntfernung
	 *            Sekundaerentfernung
	 * @param richtung
	 *            TMC-Richtung
	 */
	public TMCLocation(final Integer primaerLokation, final Integer sekundaerLokation, final Double primaerEntfernung,
			final Double sekundaerEntfernung, final TMCRichtungEnum richtung) {
		super();
		this.primaerLokation = primaerLokation;
		this.sekundaerLokation = sekundaerLokation;
		this.primaerEntfernung = primaerEntfernung;
		this.sekundaerEntfernung = sekundaerEntfernung;

		if (richtung != null) {
			this.tmcRichtung = richtung;
		} else {
			this.tmcRichtung = TMCRichtungEnum.OhneRichtung;
		}
	}

	public Integer getPrimaerLokation() {
		return primaerLokation;
	}

	public void setPrimaerLokation(final Integer primaerLokation) {
		this.primaerLokation = primaerLokation;
	}

	public Integer getSekundaerLokation() {
		return sekundaerLokation;
	}

	public void setSekundaerLokation(final Integer sekundaerLokation) {
		this.sekundaerLokation = sekundaerLokation;
	}

	public Double getPrimaerEntfernung() {
		return primaerEntfernung;
	}

	public void setPrimaerEntfernung(final Double primaerEntfernung) {
		this.primaerEntfernung = primaerEntfernung;
	}

	public Double getSekundaerEntfernung() {
		return sekundaerEntfernung;
	}

	public void setSekundaerEntfernung(final Double sekundaerEntfernung) {
		this.sekundaerEntfernung = sekundaerEntfernung;
	}

	public TMCRichtungEnum getTmcRichtung() {
		return tmcRichtung;
	}

}
